==> estateplat-common-1.1.0-20161031.065341-211-sources.jar: cn/gtmap/estateplat/model/exchange/transition/QzHysyq.java <==
package cn.gtmap.estateplat.model.exchange.transition;

import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import java.io.Serializable;
import java.util.Date;

/**
 * Created with IntelliJ IDEA.
 * 海域（含无居民海岛）使用权信息
 * User: lj
 * Date: 15-11-19
 * Time: 下午2:20
 * To change this template use File | Settings | File Templates.
 */
@Table(name = "qz_hysyq")
@XmlAccessorType(XmlAccessType.FIELD)
public class QzHysyq implements Serializable {
    @Id
    //权利编号
    @XmlElement(name = "qlbh")
    private String qlbh;
    //不动产单元编号
    @XmlElement(name = "bdcdybh")
    private String bdcdybh;
    //业务号
    @XmlElement(name = "ywh")
    private String ywh;
    //海籍号
    @XmlElement(name = "hjh")
    private String hjh;
    //权利类型
    @XmlElement(name = "qllx")
    private String qllx;
    //使用权面积
    @XmlElement(name = "syqmj")
    private Double syqmj;
    //使用权起始时间
    @XmlElement(name = "syqqssj")
    private Date syqqssj;
    //使用权结束时间
    @XmlElement(name = "syqjssj")
    private Date syqjssj;
    //使用金总额
    @XmlElement(name = "syjze")
    private Double syjze;
    //使用金标准依据
    @XmlElement(name = "syjbzyj")
    private String syjbzyj;
    //使用金缴纳情况
    @XmlElement(name = "syjjnqk")
    private String syjjnqk;
    //备注
    @XmlElement(name = "bz")
    private String bz;
    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次业务号
    private String yywh;

    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次产权证号
    private String ycqzh;

    public String getYywh() {
        return yywh;
    }

    public void setYywh(String yywh) {
        this.yywh = yywh;
    }

    public String getQlbh() {
        return qlbh;
    }

    public void setQlbh(String qlbh) {
        this.qlbh = qlbh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getHjh() {
        return hjh;
    }

    public void setHjh(String hjh) {
        this.hjh = hjh;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public Double getSyqmj() {
        return syqmj;
    }

    public void setSyqmj(Double syqmj) {
        this.syqmj = syqmj;
    }

    public Date getSyqqssj() {
        return syqqssj;
    }

    public void setSyqqssj(Date syqqssj) {
        this.syqqssj = syqqssj;
    }

    public Date getSyqjssj() {
        return syqjssj;
    }

    public void setSyqjssj(Date syqjssj) {
        this.syqjssj = syqjssj;
    }

    public Double getSyjze() {
        return syjze;
    }

    public void setSyjze(Double syjze) {
        this.syjze = syjze;
    }

    public String getSyjbzyj() {
        return syjbzyj;
    }

    public void setSyjbzyj(String syjbzyj) {
        this.syjbzyj = syjbzyj;
    }

    public String getSyjjnqk() {
        return syjjnqk;
    }

    public void setSyjjnqk(String syjjnqk) {
        this.syjjnqk = syjjnqk;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getYcqzh() {
        return ycqzh;
    }

    public void setYcqzh(String ycqzh) {
        this.ycqzh = ycqzh;
    }
}

==> estateplat-common-1.2.4-20191226.024638-230-sources.jar: cn/gtmap/estateplat/model/exchange/transition/QzHysyq.java <==
package cn.gtmap.estateplat.model.exchange.transition;

import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import java.io.Serializable;
import java.util.Date;

/**
 * Created with IntelliJ IDEA.
 * 海域（含无居民海岛）使用权信息
 * User: lj
 * Date: 15-11-19
 * Time: 下午2:20
 * To change this template use File | Settings | File Templates.
 */
@Table(name = "qz_hysyq")
@XmlAccessorType(XmlAccessType.FIELD)
public class QzHysyq implements Serializable {
    @Id
    //权利编号
    @XmlElement(name = "qlbh")
    private String qlbh;
    //不动产单元编号
    @XmlElement(name = "bdcdybh")
    private String bdcdybh;
    //业务号
    @XmlElement(name = "ywh")
    private String ywh;
    //海籍号
    @XmlElement(name = "hjh")
    private String hjh;
    //权利类型
    @XmlElement(name = "qllx")
    private String qllx;
    //使用权面积
    @XmlElement(name = "syqmj")
    private Double syqmj;
    //使用权起始时间
    @XmlElement(name = "syqqssj")
    private Date syqqssj;
    //使用权结束时间
    @XmlElement(name = "syqjssj")
    private Date syqjssj;
    //使用金总额
    @XmlElement(name = "syjze")
    private Double syjze;
    //使用金标准依据
    @XmlElement(name = "syjbzyj")
    private String syjbzyj;
    //使用金缴纳情况
    @XmlElement(name = "syjjnqk")
    private String syjjnqk;
    //备注
    @XmlElement(name = "bz")
    private String bz;
    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次业务号
    private String yywh;

    //涉及相关证书、证明进行转移、变更时，填写对应证书、证明的不动产登记的上次产权证号
    private String ycqzh;

    //登簿人
    @XmlElement(name = "dbr")
    private String dbr;

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getYywh() {
        return yywh;
    }

    public void setYywh(String yywh) {
        this.yywh = yywh;
    }

    public String getQlbh() {
        return qlbh;
    }

    public void setQlbh(String qlbh) {
        this.qlbh = qlbh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getHjh() {
        return hjh;
    }

    public void setHjh(String hjh) {
        this.hjh = hjh;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public Double getSyqmj() {
        return syqmj;
    }

    public void setSyqmj(Double syqmj) {
        this.syqmj = syqmj;
    }

    public Date getSyqqssj() {
        return syqqssj;
    }

    public void setSyqqssj(Date syqqssj) {
        this.syqqssj = syqqssj;
    }

    public Date getSyqjssj() {
        return syqjssj;
    }

    public void setSyqjssj(Date syqjssj) {
        this.syqjssj = syqjssj;
    }

    public Double getSyjze() {
        return syjze;
    }

    public void setSyjze(Double syjze) {
        this.syjze = syjze;
    }

    public String getSyjbzyj() {
        return syjbzyj;
    }

    public void setSyjbzyj(String syjbzyj) {
        this.syjbzyj = syjbzyj;
    }

    public String getSyjjnqk() {
        return syjjnqk;
    }

    public void setSyjjnqk(String syjjnqk) {
        this.syjjnqk = syjjnqk;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getYcqzh() {
        return ycqzh;
    }

    public void setYcqzh(String ycqzh) {
        this.ycqzh = ycqzh;
    }
}
